/**
 * 
 */
package net.bigeon.gclc.swt;

/*-
 * #%L
 * GCLC swt
 * %%
 * Copyright (C) 2015 - 2018 Bigeon
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.*;

import java.io.IOException;

import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Text;
import org.junit.Test;
import org.mockito.invocation.InvocationOnMock;
import org.mockito.stubbing.Answer;

import net.bigeon.gclc.manager.PipedConsoleOutput;

/** @author Emmanuel Bigeon */
public class ConsoleOutputManagerTest {
    private final Text                 text    = mock(Text.class);
    private final ConsoleOutputManager com     = new ConsoleOutputManager(text);
    private final Display              display = mock(Display.class);
    {
        when(text.getDisplay()).thenReturn(display);
        doAnswer(new Answer<Object>() {
            /* (non-Javadoc)
             * @see
             * org.mockito.stubbing.Answer#answer(org.mockito.invocation.InvocationOnMock) */
            @Override
            public Object answer(final InvocationOnMock invocation) throws Throwable {
                final Runnable runnable = invocation.getArgument(0);
                runnable.run();
                return null;
            }
        }).when(display).syncExec(any(Runnable.class));
    }

    /** Test method for
     * {@link net.bigeon.gclc.swt.ConsoleOutputManager#appendLine(java.lang.String)}. */
    @Test
    public void testAppendConsoleOutput() {
        when(text.getText()).thenReturn("", "abc",
                "abc" + System.lineSeparator() + "def");
        com.appendLine("abc");
        verify(text).append("abc");
        com.appendLine("def");
        verify(text).append(System.lineSeparator());
        verify(text).append("def");
    }

    @Test
    public void testSetManager() throws IOException, InterruptedException {
        final PipedConsoleOutput output = mock(PipedConsoleOutput.class);
        com.setManager(output);
        com.setManager(output);

        try (PipedConsoleOutput output2 = new PipedConsoleOutput()) {
            com.setManager(output2);
            output2.println("line");
            final Thread forwardThread = com.getForwardThread();
            forwardThread.join(500);
            com.setManager(null);
            forwardThread.join();
            verify(text).append("line");
        }
    }
}
