/*
 * ralph.runner, Runs RALPH (belongs to IREQ) in sequence for several days
 * Copyright (C) 2016-2018 E. Bigeon
 * mailto:emmanuel@bigeon.fr
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
/**
 * 
 */
package net.bigeon.gclc.command.base;

/*-
 * #%L
 * Generic Command Ligne console
 * %%
 * Copyright (C) 2014 - 2018 Bigeon
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */
import java.io.IOException;
import java.text.MessageFormat;
import java.util.Arrays;

import net.bigeon.gclc.command.Command;
import net.bigeon.gclc.exception.CommandRunException;
import net.bigeon.gclc.manager.ConsoleInput;
import net.bigeon.gclc.manager.ConsoleOutput;

/** A command printing test to the console.
 * <p>
 * This command mimics the effect of the echo command in linux system. The
 * difference is this command accepts java like formatting.
 * 
 * <pre>
 * echo.execute(out, in, "My Formatted {0}, with {1}", "message", "short arguments");
 * </pre>
 * 
 * @author Emmanuel Bigeon */
public class EchoCommand extends Command {

    /** Create the command.
     * 
     * @param name the command name */
    public EchoCommand(final String name) {
        super(name);
    }

    /* (non-Javadoc)
     * @see
     * fr.bigeon.gclc.command.ICommand#execute(fr.bigeon.gclc.manager.ConsoleOutput,
     * fr.bigeon.gclc.manager.ConsoleInput, java.lang.String[]) */
    @Override
    public void execute(final ConsoleOutput out, final ConsoleInput in,
            final String... args) throws CommandRunException {
        try {
            if (args.length == 1) {
                out.print(args[0]);
            }
            if (args.length > 1) {
                out.print(MessageFormat.format(args[0],
                        (Object[]) Arrays.copyOfRange(args, 1, args.length)));
            }
            out.println();
        } catch (final IOException e) {
            throw new CommandRunException("Printing failed", e);
        }
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.command.ICommand#tip() */
    @Override
    public String tip() {
        return "Print the message";
    }

    /* (non-Javadoc)
     * @see fr.bigeon.gclc.command.Command#usageDetail() */
    @Override
    protected String usageDetail() {
        return "A formatted message can be used";
    }

}
